# surf-report

[Spectral analysis](https://upcommons.upc.edu/bitstream/handle/2099.1/6034/06.pdf?sequence=7) of [real time raw spectral wave information](https://www.ndbc.noaa.gov/data_spec.shtml) from [NOAA](https://www.ndbc.noaa.gov/), calculating trends by plotting spectral moments.
![Significant Wave Height](https://github.com/noah-de/surf-report/blob/master/SWH.png)
